#
# spec file for package transifex-client
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           transifex-client
Version:        0.14.4
Release:        2.1
Summary:        Transifex Command-line Client
License:        GPL-2.0-only
Group:          Productivity/Text/Utilities
URL:            https://github.com/transifex/transifex-client
Source:         https://github.com/transifex/transifex-client/archive/%{version}.tar.gz
# https://github.com/transifex/transifex-client/pull/314
Patch0:         transifex-client-no-mock.patch
# https://github.com/transifex/transifex-client/pull/316
Patch1:         transifex-client-fix-test-on-32bit.patch
BuildRequires:  python-rpm-macros
BuildRequires:  python3-GitPython
BuildRequires:  python3-pytest
BuildRequires:  python3-python-slugify
BuildRequires:  python3-requests >= 2.19.1
BuildRequires:  python3-setuptools
BuildRequires:  python3-six < 2.0.0
BuildRequires:  python3-urllib3 >= 1.24.2
Requires:       python3-python-slugify
Requires:       python3-requests >= 2.19.1
Requires:       python3-setuptools
Requires:       python3-urllib3 >= 1.24.2
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch

%description
The Transifex Command-line Client is a command line tool that enables you
to easily manage your translations within a project without the need of
an elaborate UI system.

You can use the command-line client to easily create new resources, map
locale files to translations and synchronize your Transifex project with
your local repository and vice verca. Translators and localization
managers can also use it to handle large volumes of translation files
easily and without much hassle.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
sed -i -e '1{\,^#!/usr/bin/env python,d}' txclib/cmdline.py

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
# remove pem file
rm %{buildroot}/%{python3_sitelib}/txclib/cacert.pem

mv %{buildroot}%{_bindir}/tx %{buildroot}%{_bindir}/transifex-tx
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f %{_sysconfdir}/alternatives/tx %{buildroot}%{_bindir}/tx

%check
# test_fetch_timestamp_from_git_tree: this is not a git tree
pytest -k 'not test_fetch_timestamp_from_git_tree'

%post
%{_sbindir}/update-alternatives --install %{_bindir}/tx tx %{_bindir}/transifex-tx 20

%postun
if [ ! -e %{_bindir}/transifex-tx ] ; then
  %{_sbindir}/update-alternatives --remove tx %{_bindir}/transifex-tx
fi

%files
%defattr(-,root,root)
%doc README.md
%license LICENSE
%ghost %{_sysconfdir}/alternatives/tx
%{_bindir}/transifex-tx
%{_bindir}/tx
%{python3_sitelib}/*

%changelog
* Mon Jun 26 2023 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire python3-six: used to be pulled in by other
  dependencies, but is explicitly used in this package.
* Tue Apr 26 2022 pgajdos@suse.com
- fix tests on 32 bit arch
- added patches
  fix https://github.com/transifex/transifex-client/pull/316
  + transifex-client-fix-test-on-32bit.patch
* Tue Apr 26 2022 pgajdos@suse.com
- version update to 0.14.4
  * Patch issue 317
  * Change download path when supplied language is source language
  * Fix for CLI option of custom CA certificate bundle file
  * Use authored date as git timestamp
  * CLI option for custom CA certificate bundle file
  * New flag to compare file timestamp through git and slugify update
- do not require python-mock for build
- added patches
  fix https://github.com/transifex/transifex-client/pull/314
  + transifex-client-no-mock.patch
* Wed Jan 12 2022 Dirk Müller <dmueller@suse.com>
- add python-rpm-macros dependency
* Thu Aug 26 2021 pgajdos@suse.com
- %%check: do not use setup.py test
* Fri Jun 12 2020 Antonio Larrosa <alarrosa@suse.com>
- Use update-alternatives for the tx binary so users can
  install in the same system transifex-client and python3-afdko
* Fri Jun 12 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 0.13.9:
  * Change symlink loop prevention approach
- Update to 0.13.8:
  * Tx-client is now able to follow any symbolic links while
    pushing content to Transifex.
- Update to 0.13.7:
  * Loosen up dependency versions and support Python 3.8
  * Add missing description content type in setup.py
- Update to 0.13.6:
  * Extend Python support
- Update to 0.13.5:
  * Pin dependencies to avoid incompatibilities between packages
- Update to 0.13.4:
  * Support Python 3.7
  * Make the wizard handle unknown file formats gracefully
- Update to 0.13.3:
  * Use the TX_TOKEN environment variable to set your Transifex API
    token. This essentially replaces the --token argument in the tx
    init command, and does not write any credentials in the
    .transifexrc file.
  * Add the --no-interactive argument in the tx pull command, for
    the case where no user input is required. This is needed in
    some cases where a CI does not want to proceed with user input
    and needs to fail silently.
- Update to 0.13.2:
  * Push and pull files more quickly by using the new --parallel
    option with tx push and tx pull to make parallel requests. This
    is a beta feature - be careful when using it with many files as
    it may cause you to hit your API rate limits.
  * --expression is now a named argument for tx config mapping so
    it’s consistent with the tx config mapping-bulk command with
    regard to how you pass a file path expression.
  * The algorithm for locating translation files has been optimized
    to improve performance in cases where you have many files in
    your working directory.
- Update to 0.13.1:
  * Fix some python 3 compatibility issues
  * Fix CI for python 3
  * Add Python 3.6 in the supported versions
- Update to 0.13.0:
  * Rename set command to config while maintaining backwards
    compatibility.
  * --auto-local, --auto-remote options have become mapping and
    mapping-remote subcommands. Backwards compatibility has been
    maintained and the options (and subcommands) are supported both
    when using tx set and tx config commands.
  * Introduce mapping-bulk subcommand to tx config command.
    mapping-bulk is similar to mapping but configures a whole
    directory of files and not a single file.
  * Support branch specific push / pull using the --branch option.
  * Add interactive wizard for tx config command. Interactive wizard
    is triggered by default after tx init if --skipsetup option is
    not passed and by the tx config if called without any options
    or subcommands.
- Update to 0.12.5:
  * Support for Basic Authentication when using the client behind
    a proxy
  * Support for sourceastranslation and onlyreviewed modes when
    pulling files
  * Return non-zero exit codes on errors
  * tx --version now includes information about the Python version
    and architecture you’re running
  * Some updates and minor fixes in logging/error messages
* Wed May  3 2017 tchvatal@suse.com
- Version update to 0.12.4:
  * XLIFF and tokens support
- Switch to python3, no need to keep python2 around
* Tue Sep 13 2016 astieger@suse.com
- license is GPL-2.0, "or later" is not mentioned anywhere upstream
* Sat Sep 10 2016 tchvatal@suse.com
- Add python-urllib3 to requires
* Wed Aug 24 2016 tchvatal@suse.com
- Update download url to github
* Wed Aug 24 2016 buschmann23@opensuse.org
- Update to 0.12.2
  * better proxy support
- Update to 0.12.1
  * support new style URLs
  * better error handling
- Update to 0.12.b
  * fix support for downloading docx, xlsx
* Fri Jan  8 2016 tchvatal@suse.com
- Update/downgrade to 0.11 that is newer than 0.11.1beta...
  * Few extra commits over the 0.11.1beta
* Fri Nov  6 2015 buschmann23@opensuse.org
- Add python-setuptools to the Requires
* Fri Mar 13 2015 tchvatal@suse.com
- Version bump to 0.11.1.beta:
  * Various small bugfixes
* Wed May 28 2014 tchvatal@suse.com
- Version bump to 0.11.beta:
  * drop our patch of using system-urllib3.patch which broke things
    as upstream does not really work that way
  * Enable tests again as upstream tarball now has them.
* Thu Mar 20 2014 speilicke@suse.com
- Use PyPI source URL
- Drop %%clean section, the official tarball doesn't include tests
- Correct macro usage to fix SLE build
* Wed Dec 18 2013 tchvatal@suse.com
- Version bump to 0.10:
  * try to use urllib3
  * fix various mitm attacks over this
- Add patch system-urllib3.patch which does exactly what name say.
  * Should also fix bnc#855579
- Enable test execution so we see if it is borked or not.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Oct  9 2013 tchvatal@suse.com
- Version bump to 0.9.2:
  * upstream changed distribution to be only from github
  * fix few issues when communicating with transifex api
* Thu May 23 2013 tchvatal@suse.com
- Version bump to 0.9
  * SSL layer updates
  * various build fixes
* Wed Jan  2 2013 toddrme2178@gmail.com
- Fix building on SLES
* Sat Dec  1 2012 tchvatal@suse.com
- Update the spec to be up par with suse stuff
* Tue Oct 16 2012 i@marguerite.su
- initial package 0.8
  * Enable support for compressed responses from Transifex.
  * Specify a custom User-Agent header for the HTTP requests performed by the client.
  * Specify a timeout of 5min for each request, so that the client does not block indefinitely.
  * Offer to migrate the .transifexrc file to use secure (SSL) connections by default, when connecting to Transifex servers, and the new domain, Transifex.com. The migration process does not update the .tx/config file, since that file might be part of a repository.
  * Send warning messages to standard output. This means that only actual errors are sent to standard error and, as a result, redirecting the output works correctly.
  * Don’t use colors, when the output is not a TTY. As a result, the output of the client when piped to other programs will not be garbled.
